@@ -76,97 +76,6 @@ namespace BOOM {
               list_element_name,
               final_state));
     }
-
-    //---------------------------------------------------------------------------
-    // Stores the final state in the MultivariateStateSpaceRegressionModel as a
-    // list of matrices, one for each series.  It is assumed the model has
-    // series-specific state.  If not, it is the caller's responsibility to
-    // avoid adding this element to the io manager.
-    class SubordinateFinalStateListElement
-        : public RListIoElement {
-     public:
-      SubordinateFinalStateListElement(
-          MultivariateStateSpaceRegressionModel *model,
-          std::vector<BOOM::Vector> *streaming_buffer)
-          : RListIoElement("series.specific.final.state"),
-            model_(model),
-            streaming_buffer_(streaming_buffer)
-      {}
-
-      // Args:
-      //   niter:  The number of iterations to be written.
-      //
-      // Returns:
-      //   An R list of R matrices.
-      SEXP prepare_to_write(int niter) override {
-        RMemoryProtector protector;
-        SEXP r_buffer = protector.protect(
-            Rf_allocVector(VECSXP, model_->nseries()));
-        for (int i = 0; i < model_->nseries(); ++i) {
-          SEXP r_matrix = protector.protect(Rf_allocMatrix(
-              REALSXP,
-              niter,
-              model_->series_specific_model(i)->state_dimension()));
-          matrix_views_.push_back(BOOM::ToBoomMutableMatrixView(r_matrix));
-        }
-        StoreBuffer(r_buffer);
-        return r_buffer;
-      }
-
-      // Args:
-      //   r_object: A model object fit with 'mbsts'.  The object contains
-      //     subordinate state that was previously written by this->write().
-      void prepare_to_stream(SEXP r_object) override {
-        if (!streaming_buffer_) return;
-        RListIoElement::prepare_to_stream(r_object);
-        SEXP r_buffer = rbuffer();
-        int nseries = Rf_length(r_buffer);
-        if (nseries != model_->nseries()) {
-          report_error("Number of series in the final state buffer "
-                       "must match model object.");
-        }
-        for (int i = 0; i < nseries; ++i) {
-          matrix_views_.push_back(ToBoomMutableMatrixView(
-              VECTOR_ELT(r_buffer, i)));
-        }
-      }
-
-      void write() override {
-        int row_index = next_position();
-        for (int i = 0; i < model_->nseries(); ++i) {
-          matrix_views_[i].row(row_index) =
-              model_->series_specific_model(i)->state().last_col();
-        }
-      }
-      
-      void stream() override {
-        if (streaming_buffer_) {
-          int row_index = next_position();
-          for (int i = 0; i < model_->nseries(); ++i) {
-            (*streaming_buffer_)[i] = matrix_views_[i].row(row_index);
-          }
-        }
-      }
-      
-     private:
-      MultivariateStateSpaceRegressionModel *model_;
-      std::vector<BOOM::SubMatrix> matrix_views_;
-      std::vector<BOOM::Vector> *streaming_buffer_;
-    };
-
-    //--------------------------------------------------------------------------
-    void SharedStateModelFactory::SaveSubordinateFinalState(
-        MultivariateStateSpaceRegressionModel *model,
-        std::vector<BOOM::Vector> *final_state,
-        const std::string &list_element_name) {
-      if (!model && final_state && io_manager()) return;
-      if (model->has_series_specific_state()) {
-        for (int i = 0; i < model->nseries(); ++i) {
-          
-        }
-      }
-      
-    }
     
     Ptr<SharedStateModel>
     SharedStateModelFactory::CreateSharedStateModel(
@@ -256,10 +165,6 @@ namespace BOOM {
 
       // Set the io manager, if there is one.
       if (io_manager()) {
-        io_manager()->add_list_element(new GenericVectorListElement(
-            new SharedLocalLevelVarianceManager(state_model.get()),
-            prefix + "shared.sigma.level"));
-
         io_manager()->add_list_element(new MatrixListElement(
             state_model->coefficient_model()->Beta_prm(),
             prefix + "shared.local.level.coefficients"));
